# Authors

- Joseph Kenny <<kenny@arch.ethz.ch>> [@jckenny59](https://github.com/jckenny59)
- Daniela Mitterberger <<mitterberger@princeton.edu>> [@dmitterberger](https://github.com/dmitterberger)
- Gonzalo Casas <<casas@arch.ethz.ch>> [@gonzalocasas](https://github.com/gonzalocasas)
